Struct actix_utils::counter::Counter [−][src]
pub struct Counter(_);
Simple counter with ability to notify task on reaching specific number
Counter could be cloned, total n-count is shared across all clones.
Implementations
impl Counter[src]
pub fn new(capacity: usize) -> Self[src]
Create Counter instance with max value.
pub fn get(&self) -> CounterGuard[src]
Create new counter guard, incrementing the counter.
pub fn available(&self, cx: &mut Context<'_>) -> bool[src]
Notify current task and return true if counter is at capacity.
pub fn total(&self) -> usize[src]
Get total number of acquired guards.