Enum actix_utils::future::Either[][src]

pub enum Either<L, R> {
    Left {
        value: L,
    },
    Right {
        value: R,
    },
}

Combines two different futures that have the same output type.

Construct variants with Either::left and Either::right.

Examples

use actix_utils::future::{ready, Ready, Either};

let res = Either::<_, Ready<usize>>::left(ready(42));
assert_eq!(res.await, 42);

let res = Either::<Ready<usize>, _>::right(ready(43));
assert_eq!(res.await, 43);

Variants

Left

A value of type L.

Fields of Left

value: L
Right

A value of type R.

Fields of Right

value: R

Implementations

impl<L, R> Either<L, R>[src]

pub fn left(value: L) -> Either<L, R>

Notable traits for Either<L, R>

impl<L, R> Future for Either<L, R> where
    L: Future,
    R: Future<Output = L::Output>, 
type Output = L::Output;
[src]

Creates new Either using left variant.

pub fn right(value: R) -> Either<L, R>

Notable traits for Either<L, R>

impl<L, R> Future for Either<L, R> where
    L: Future,
    R: Future<Output = L::Output>, 
type Output = L::Output;
[src]

Creates new Either using right variant.

impl<T> Either<T, T>[src]

pub fn into_inner(self) -> T[src]

Unwraps into inner value when left and right have a common type.