[][src]Struct actix_utils::counter::Counter

pub struct Counter(_);

Simple counter with ability to notify task on reaching specific number

Counter could be cloned, total ncount is shared across all clones.

Methods

impl Counter[src]

pub fn new(capacity: usize) -> Self[src]

Create Counter instance and set max value.

pub fn get(&self) -> CounterGuard[src]

pub fn available(&self) -> bool[src]

Check if counter is not at capacity

pub fn total(&self) -> usize[src]

Get total number of acquired counts