Module actix_utils::future [−][src]
Asynchronous values.
Structs
| PollFn | A Future driven by the inner function. |
| Ready | Future for the |
Enums
| Either | Combines two different futures that have the same output type. |
Functions
| err | Creates a future that is immediately ready with an error value. |
| ok | Creates a future that is immediately ready with a success value. |
| poll_fn | Creates a future driven by the provided function that receives a task context. |
| ready | Creates a future that is immediately ready with a value. |