Enum actix_utils::future::Either [−][src]
pub enum Either<L, R> {
Left {
value: L,
},
Right {
value: R,
},
}Combines two different futures that have the same output type.
Construct variants with Either::left and Either::right.
Examples
use actix_utils::future::{ready, Ready, Either}; let res = Either::<_, Ready<usize>>::left(ready(42)); assert_eq!(res.await, 42); let res = Either::<Ready<usize>, _>::right(ready(43)); assert_eq!(res.await, 43);
Variants
A value of type L.
A value of type R.
Implementations
impl<L, R> Either<L, R>[src]
pub fn left(value: L) -> Either<L, R>ⓘ[src]
Creates new Either using left variant.
pub fn right(value: R) -> Either<L, R>ⓘ[src]
Creates new Either using right variant.
impl<T> Either<T, T>[src]
pub fn into_inner(self) -> T[src]
Unwraps into inner value when left and right have a common type.