[−][src]Struct actix_utils::oneshot::Receiver
A future representing the completion of a computation happening elsewhere in memory.
This is created by the unsync::oneshot::channel function and is equivalent
in functionality to sync::oneshot::Receiver except that it cannot be sent
across threads.
Methods
impl<T> Receiver<T>[src]
pub fn close(&mut self)[src]
Gracefully close this receiver, preventing sending any future messages.
Any send operation which happens after this method returns is
guaranteed to fail. Once this method is called the normal poll method
can be used to determine whether a message was actually sent or not. If
Canceled is returned from poll then no message was sent.